import { Construct } from "constructs";
import * as cdk from "aws-cdk-lib";
import * as dynamodb from "aws-cdk-lib/aws-dynamodb";
/**
 * Stack properties for the DebugStack.
 */
export interface DebugStackProps extends cdk.StackProps {
    /**
     * S3 bucket to store large websocket payloads.
     */
    payloadBucketArn?: string;
    /**
     * Lambda function props for WebSocket request handlers.
     */
    websocketHandlerRoleArn?: string;
    cdk?: {
        /**
         * Override the settings of the internally created DynamoDB table
         */
        table?: Omit<dynamodb.TableProps, "partitionKey" | "sortKey">;
    };
}
/**
 * The `DebugStack` construct is used internally to create the resources needed to power Live Lambda Development. Note that, the `DebugStack` construct should only be created inside the [`DebugApp`](DebugApp).
 */
export declare class DebugStack extends cdk.Stack {
    readonly stage: string;
    private readonly api;
    private readonly table;
    private readonly bucket;
    constructor(scope: Construct, id: string, props?: DebugStackProps);
    private addApiRoute;
    private static checkForEnvInProps;
}
